==> haskell-base64-0.4.2.4-99-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-base64.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 base64
version:              0.4.2.4
visibility:           public
id:                   base64-0.4.2.4-7UF38kSEquK4m3L2XQGIPV
key:                  base64-0.4.2.4-7UF38kSEquK4m3L2XQGIPV
license:              BSD-3-Clause
copyright:            (c) 2019-2022 Emily Pillmore
maintainer:           emilypi@cohomolo.gy
author:               Emily Pillmore
homepage:             https://github.com/emilypi/base64
synopsis:             A modern RFC 4648-compliant Base64 library
description:
    RFC 4648-compliant Base64 with an eye towards performance and modernity (additional support for RFC 7049 standards)

category:             Data
abi:                  07313e7dbe99bcb3740577adf882079d
exposed:              True
exposed-modules:
    Data.ByteString.Base64 Data.ByteString.Base64.URL
    Data.ByteString.Lazy.Base64 Data.ByteString.Lazy.Base64.URL
    Data.ByteString.Short.Base64 Data.ByteString.Short.Base64.URL
    Data.Text.Encoding.Base64 Data.Text.Encoding.Base64.Error
    Data.Text.Encoding.Base64.URL Data.Text.Lazy.Encoding.Base64
    Data.Text.Lazy.Encoding.Base64.URL Data.Text.Short.Encoding.Base64
    Data.Text.Short.Encoding.Base64.URL

hidden-modules:
    Data.ByteString.Base64.Internal
    Data.ByteString.Base64.Internal.Head
    Data.ByteString.Base64.Internal.Tables
    Data.ByteString.Base64.Internal.Tail
    Data.ByteString.Base64.Internal.Utils
    Data.ByteString.Base64.Internal.W16.Loop
    Data.ByteString.Base64.Internal.W32.Loop
    Data.ByteString.Base64.Internal.W64.Loop

import-dirs:          /usr/lib/ghc-9.4.8/site-local/base64-0.4.2.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/base64-0.4.2.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/base64-0.4.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-base64
hs-libraries:         HSbase64-0.4.2.4-7UF38kSEquK4m3L2XQGIPV
depends:
    base-4.17.2.1 bytestring-0.11.5.3 deepseq-1.4.8.0 text-2.0.2
    text-short-0.1.6-JxZmomqfmBPHr8e1Kgb0nA

haddock-interfaces:   /usr/share/doc/haskell-base64/html/base64.haddock
haddock-html:         /usr/share/doc/haskell-base64/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-base64-0.4.2.4-104-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-base64.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 base64
version:              0.4.2.4
visibility:           public
id:                   base64-0.4.2.4-1c0wYYG314IBiTDRSOESqf
key:                  base64-0.4.2.4-1c0wYYG314IBiTDRSOESqf
license:              BSD-3-Clause
copyright:            (c) 2019-2022 Emily Pillmore
maintainer:           emilypi@cohomolo.gy
author:               Emily Pillmore
homepage:             https://github.com/emilypi/base64
synopsis:             A modern RFC 4648-compliant Base64 library
description:
    RFC 4648-compliant Base64 with an eye towards performance and modernity (additional support for RFC 7049 standards)

category:             Data
abi:                  07122af07d2433cf312dce9df6a9fc18
exposed:              True
exposed-modules:
    Data.ByteString.Base64 Data.ByteString.Base64.URL
    Data.ByteString.Lazy.Base64 Data.ByteString.Lazy.Base64.URL
    Data.ByteString.Short.Base64 Data.ByteString.Short.Base64.URL
    Data.Text.Encoding.Base64 Data.Text.Encoding.Base64.Error
    Data.Text.Encoding.Base64.URL Data.Text.Lazy.Encoding.Base64
    Data.Text.Lazy.Encoding.Base64.URL Data.Text.Short.Encoding.Base64
    Data.Text.Short.Encoding.Base64.URL

hidden-modules:
    Data.ByteString.Base64.Internal
    Data.ByteString.Base64.Internal.Head
    Data.ByteString.Base64.Internal.Tables
    Data.ByteString.Base64.Internal.Tail
    Data.ByteString.Base64.Internal.Utils
    Data.ByteString.Base64.Internal.W16.Loop
    Data.ByteString.Base64.Internal.W32.Loop
    Data.ByteString.Base64.Internal.W64.Loop

import-dirs:          /usr/lib/ghc-9.4.8/site-local/base64-0.4.2.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/base64-0.4.2.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/base64-0.4.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-base64
hs-libraries:         HSbase64-0.4.2.4-1c0wYYG314IBiTDRSOESqf
depends:
    base-4.17.2.1 bytestring-0.11.5.3 deepseq-1.4.8.0 text-2.0.2
    text-short-0.1.6-DFy7kIIkCnA3mhKjYr8Fzb

haddock-interfaces:   /usr/share/doc/haskell-base64/html/base64.haddock
haddock-html:         /usr/share/doc/haskell-base64/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
